@@ -68,6 +68,7 @@ module SiSU_AO_DocumentStructureExtract
       @pbn=SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_new])
       @pbl=SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_line])
       @per=SiSU_AO_Persist::PersistDocStructExt.new
+      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def ln_get(lv)
       case lv
@@ -1229,23 +1230,25 @@ module SiSU_AO_DocumentStructureExtract
         }
       end
       tuned_file << @pb
-      h={
-        ln: 1,
-        lc: 1,
-        obj: 'Metadata',
-        autonum_: false,
-        ocn_: false,
-      }
-      tuned_file << SiSU_AO_DocumentStructure::ObjectHeading.new.heading_insert(h)
-      h={
-        ln: 4,
-        lc: 2,
-        obj: 'SiSU Metadata, document information',
-        name: 'metadata',
-        autonum_: false,
-        ocn_: false,
-      }
-      tuned_file << SiSU_AO_DocumentStructure::ObjectHeading.new.heading_insert(h)
+      if @make.build.metadata?
+        h={
+          ln: 1,
+          lc: 1,
+          obj: 'Metadata',
+          autonum_: false,
+          ocn_: false,
+        }
+        tuned_file << SiSU_AO_DocumentStructure::ObjectHeading.new.heading_insert(h)
+        h={
+          ln: 4,
+          lc: 2,
+          obj: 'SiSU Metadata, document information',
+          name: 'metadata',
+          autonum_: false,
+          ocn_: false,
+        }
+        tuned_file << SiSU_AO_DocumentStructure::ObjectHeading.new.heading_insert(h)
+      end
       h={
         obj: 'eof',
       }
