@@ -7,11 +7,11 @@
 *** constants, system environment, resource control and configuration details
 
 ** Author: Ralph Amissah
-  <ralph@amissah.com>
-  <ralph.amissah@gmail.com>
+  [ralph@amissah.com]
+  [ralph.amissah@gmail.com]
 
 ** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
+  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
   All Rights Reserved.
 
 ** License: GPL 3 or later:
@@ -31,14 +31,12 @@
   more details.
 
   You should have received a copy of the GNU General Public License along with
-  this program. If not, see <http://www.gnu.org/licenses/>.
+  this program. If not, see [http://www.gnu.org/licenses/].
 
   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
-  <http://www.fsf.org/licensing/licenses/gpl.html>
-  <http://www.gnu.org/licenses/gpl.html>
-
-  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+  [http://www.fsf.org/licensing/licenses/gpl.html]
+  [http://www.gnu.org/licenses/gpl.html]
 
 ** SiSU uses:
   * Standard SiSU markup syntax,
@@ -46,16 +44,16 @@
   * Standard SiSU object citation numbering and system
 
 ** Hompages:
-  <http://www.jus.uio.no/sisu>
-  <http://www.sisudoc.org>
+  [http://www.jus.uio.no/sisu]
+  [http://www.sisudoc.org]
 
 ** Git
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/constants.rb;hb=HEAD>
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/constants.rb;hb=HEAD]
 
 =end
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
-YEAR='2015'
+YEAR='2016'
 Sfx={
   txt:                       '.txt',
   txt_textile:               '.textile',
@@ -78,6 +76,7 @@ Sfx={
   epub:                      '.epub',
   epub_xhtml:                '.xhtml',
   odt:                       '.odt',
+  json:                      '.json',
   pdf:                       '.pdf',
   manpage:                   '.1',
   info:                      '.info',
