@@ -1610,78 +1610,151 @@ Generated by \\href{http://www.jus.uio.no/sisu}{SiSU www.jus.uio.no/sisu } \\\\
   end
 end
 __END__
-#ack usepackage texpdf*
-#ack usepackage texpdf* |ack '\{.+?\}'
-#see sisu_texpdf_usepackage.rb
-  alltt.sty
+ag usepackage texpdf*
+ag usepackage texpdf* | ag '\{.+?\}'
+# texpdf_format.rb
+ag usepackage texpdf* | ag --only-matching '\{.+?\}'
+
+* sort & make unique
+@tex2pdf
+alltt.sty
+amssymb.sty
+babel.sty
+boites.sty
+breakurl.sty
+color.sty
+endnotes.sty
+fancyhdr.sty
+fontspec.sty
+footmisc.sty
+graphicx.sty
+inputenc.sty
+listings.sty
+longtable.sty
+manyfoot.sty
+mathptmx.sty
+multicol.sty
+parskip.sty
+polyglossia.sty
+soul.sty
+textcomp.sty
+thumbpdf.sty
+titlepic.sty
+ucs.sty
+ulem.sty
+url.sty
+xeCJK.sty
+xltxtra.sty
+xunicode.sty
+
+* debian related
+** found in
+
+alltt.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/base/alltt.sty
+amssymb.sty
+  texlive-base: /usr/share/texlive/texmf-dist/tex/latex/amsfonts/amssymb.sty
+babel.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/generic/babel/babel.sty
+boites.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/boites/boites.sty
+breakurl.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/breakurl/breakurl.sty
+color.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/graphics/color.sty
+endnotes.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/endnotes/endnotes.sty
+fancyhdr.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/fancyhdr/fancyhdr.sty
+fontspec.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/latex/fontspec/fontspec.sty
+footmisc.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/footmisc/footmisc.sty
+graphicx.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/graphics/graphicx.sty
+inputenc.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/base/inputenc.sty
+listings.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/latex/listings/listings.sty
+longtable.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/tools/longtable.sty
+manyfoot.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/ncctools/manyfoot.sty
+mathptmx.sty
+  texlive-font-utils: /usr/share/doc/texlive-doc/fonts/fontinst/examples/mathptmx/mathptmx.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/psnfss/mathptmx.sty
+multicol.sty
+  ptex-jtex: /usr/share/texmf/ajtex/multicol.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/tools/multicol.sty
+parskip.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/latex/parskip/parskip.sty
+polyglossia.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/latex/polyglossia/polyglossia.sty
+soul.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/soul/soul.sty
+textcomp.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/base/textcomp.sty
+thumbpdf.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/generic/thumbpdf/thumbpdf.sty
+titlepic.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/titlepic/titlepic.sty
+ucs.sty
+  texlive-latex-extra: /usr/share/texlive/texmf-dist/tex/latex/ucs/ucs.sty
+ulem.sty
+  texlive-plain-generic: /usr/share/texlive/texmf-dist/tex/generic/ulem/ulem.sty
+url.sty
+  texlive-latex-base: /usr/share/texlive/texmf-dist/tex/latex/url/url.sty
+xeCJK.sty
+  texlive-xetex: /usr/share/texlive/texmf-dist/tex/xelatex/xecjk/xeCJK.sty
+xltxtra.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/latex/xltxtra/xltxtra.sty
+xunicode.sty
+  texlive-latex-recommended: /usr/share/texlive/texmf-dist/tex/xelatex/xunicode/xunicode.sty
+
+** belongs to
+
+texlive-base:
   amssymb.sty
+texlive-latex-base:
+  alltt.sty
   babel.sty
-  boites.sty
   color.sty
-  endnotes.sty
   fancyhdr.sty
-  fontspec.sty
-  footmisc.sty
   graphicx.sty
   inputenc.sty
-  listings.sty
   longtable.sty
-  manyfoot.sty
+  mathptmx.sty
   multicol.sty
-  parskip.sty
-  polyglossia.sty
-  soul.sty
   textcomp.sty
-  thumbpdf.sty
+  url.sty
+texlive-latex-extra:
+  boites.sty
+  breakurl.sty
+  endnotes.sty
+  footmisc.sty
+  manyfoot.sty
+  soul.sty
   titlepic.sty
   ucs.sty
-  ulem.sty
-  url.sty
-  xetex.sty
+texlive-latex-recommended:
+  fontspec.sty
+  listings.sty
+  parskip.sty
+  polyglossia.sty
+  thumbpdf.sty
   xltxtra.sty
   xunicode.sty
----
-texlive-latex-base
+texlive-plain-generic:
+  ulem.sty
+texlive-xetex:
+  xeCJK.sty
+
+** all texlive packages used
+
 texlive-base
+texlive-latex-base
 texlive-latex-extra
 texlive-latex-recommended
+texlive-plain-generic
 texlive-xetex
-texlive-generic-recommended
----
-texlive-latex-base:
-    /usr/share/texlive/texmf-dist/tex/generic/babel/babel.sty
-    /usr/share/texlive/texmf-dist/tex/latex/base/alltt.sty
-    /usr/share/texlive/texmf-dist/tex/latex/base/inputenc.sty
-    /usr/share/texlive/texmf-dist/tex/latex/base/textcomp.sty
-    /usr/share/texlive/texmf-dist/tex/latex/fancyhdr/fancyhdr.sty
-    /usr/share/texlive/texmf-dist/tex/latex/graphics/color.sty
-    /usr/share/texlive/texmf-dist/tex/latex/graphics/graphicx.sty
-    /usr/share/texlive/texmf-dist/tex/latex/tools/longtable.sty
-    /usr/share/texlive/texmf-dist/tex/latex/tools/multicol.sty
----
-texlive-base:
-    /usr/share/texlive/texmf-dist/tex/latex/amsfonts/amssymb.sty
----
-texlive-latex-extra:
-    /usr/share/texlive/texmf-dist/tex/latex/boites/boites.sty
-    /usr/share/texlive/texmf-dist/tex/latex/endnotes/endnotes.sty
-    /usr/share/texlive/texmf-dist/tex/latex/footmisc/footmisc.sty
-    /usr/share/texlive/texmf-dist/tex/latex/ncctools/manyfoot.sty
-    /usr/share/texlive/texmf-dist/tex/latex/soul/soul.sty
-    /usr/share/texlive/texmf-dist/tex/latex/titlepic/titlepic.sty
-    /usr/share/texlive/texmf-dist/tex/latex/ucs/ucs.sty
----
-texlive-latex-recommended:
-    /usr/share/texlive/texmf-dist/tex/generic/thumbpdf/thumbpdf.sty
-    /usr/share/texlive/texmf-dist/tex/latex/fontspec/fontspec.sty
-    /usr/share/texlive/texmf-dist/tex/latex/listings/listings.sty
-    /usr/share/texlive/texmf-dist/tex/latex/parskip/parskip.sty
-    /usr/share/texlive/texmf-dist/tex/latex/url/url.sty
----
-texlive-xetex:
-    /usr/share/texlive/texmf-dist/tex/latex/xltxtra/xltxtra.sty
-    /usr/share/texlive/texmf-dist/tex/xelatex/polyglossia/polyglossia.sty
-    /usr/share/texlive/texmf-dist/tex/xelatex/xunicode/xunicode.sty
----
-texlive-generic-recommended:
-    /usr/share/texlive/texmf-dist/tex/generic/ulem/ulem.sty
+
