@@ -9,7 +9,7 @@
 ** Author: Ralph Amissah
 
 ** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
+  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
   All Rights Reserved.
 
 ** License: GPL 3 or later:
@@ -29,14 +29,12 @@
   more details.
 
   You should have received a copy of the GNU General Public License along with
-  this program. If not, see <http://www.gnu.org/licenses/>.
+  this program. If not, see [http://www.gnu.org/licenses/].
 
   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
-  <http://www.fsf.org/licensing/licenses/gpl.html>
-  <http://www.gnu.org/licenses/gpl.html>
-
-  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+  [http://www.fsf.org/licensing/licenses/gpl.html]
+  [http://www.gnu.org/licenses/gpl.html]
 
 ** SiSU uses:
   * Standard SiSU markup syntax,
@@ -44,16 +42,16 @@
   * Standard SiSU object citation numbering and system
 
 ** Hompages:
-  <http://www.jus.uio.no/sisu>
-  <http://www.sisudoc.org>
+  [http://www.jus.uio.no/sisu]
+  [http://www.sisudoc.org]
 
 ** Git
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/xml_shared.rb;hb=HEAD>
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/xml_shared.rb;hb=HEAD]
 
 ** Ralph Amissah
-  <ralph@amissah.com>
-  <ralph.amissah@gmail.com>
+  [ralph@amissah.com]
+  [ralph.amissah@gmail.com]
 
 =end
 module SiSU_XML_Munge
