@@ -404,7 +404,7 @@ proceed? }
         if File.writable?(fn)
           changelog_arr_current = IO.readlines(fn)
           changelog_arr_next=changelog_arr_current.each.map do |line|
-            if line =~/^\*\s+sisu_[0-9]+\.[0-9]+\.[0-9]+(?:_pre_rel)?\.orig\.tar\.xz \(Open commit window: [0-9]{4}-[0-9]{2}-[0-9]{2}; Pre-Release\)\)$/
+            if line =~/^\*\s+sisu_[0-9]+\.[0-9]+\.[0-9]+(?:_pre_rel)?\.orig\.tar\.xz \(Open commit window: [0-9]{4}-[0-9]{2}-[0-9]{2}; Pre-Release\)$/
               "* sisu_#{vi[:version]}.orig.tar.xz " \
               + "(#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})\n"
             else line
@@ -437,7 +437,7 @@ proceed? }
     def self.changelog_header_pre_release(vi)
       vn=version_number(vi)
       <<-WOK
-* sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release))
+* sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release)
   http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
